=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2005-09-07 10:47:36 +0000
+++ bzrlib/diff.py	2005-09-07 17:38:00 +0000
@@ -228,17 +228,17 @@
         print >>to_file, '*** renamed %s %r => %r' % (kind, old_path, new_path)
         _maybe_diff_file_or_symlink(old_label, old_path, old_tree, file_id,
                                     new_label, new_path, new_tree,
-                                    text_modified, kind, to_file)
+                                    text_modified, kind, to_file, diff_file)
 
     for path, file_id, kind in delta.modified:
         print >>to_file, '*** modified %s %r' % (kind, path)
         _maybe_diff_file_or_symlink(old_label, path, old_tree, file_id,
                                     new_label, path, new_tree,
-                                    True, kind, to_file)
+                                    True, kind, to_file, diff_file)
 
 def _maybe_diff_file_or_symlink(old_label, old_path, old_tree, file_id,
                                 new_label, new_path, new_tree, text_modified,
-                                kind, to_file):
+                                kind, to_file, diff_file):
     if text_modified:
         if kind == 'file':
             diff_file(old_label + old_path,

=== modified file 'bzrlib/revision.py'
--- bzrlib/revision.py	2005-09-06 11:09:03 +0000
+++ bzrlib/revision.py	2005-09-07 16:31:54 +0000
@@ -24,9 +24,17 @@
 
     Includes the revision_id and revision_sha1.
     """
-    revision_id = None
-    revision_sha1 = None
+
+    def __eq__(self, other):
+        try:
+            return self.revision_id == other.revision_id and \
+                   self.revision_sha1 == other.revision_sha1
+        except AttributeError:
+            return False
+
     def __init__(self, revision_id, revision_sha1=None):
+        self.revision_id = None
+        self.revision_sha1 = None
         if revision_id == None \
            or isinstance(revision_id, basestring):
             self.revision_id = revision_id
@@ -54,22 +62,38 @@
     parents
         List of parent revisions, each is a RevisionReference.
     """
-    inventory_id = None
-    inventory_sha1 = None
-    revision_id = None
-    timestamp = None
-    message = None
-    timezone = None
-    committer = None
     
-    def __init__(self, **args):
-        self.__dict__.update(args)
-        self.parents = []
+    def __init__(self, inventory_id=None, inventory_sha1=None, 
+                       revision_id=None, timestamp=None,
+                       message=None, timezone=None,
+                       committer=None, parents=None):
+        self.inventory_id = inventory_id
+        self.inventory_sha1 = inventory_sha1
+        self.revision_id = revision_id
+        self.timestamp = timestamp
+        self.message = message
+        self.timezone = timezone
+        self.committer = committer
+        if parents is not None:
+            self.parents = parents
+        else:
+            self.parents = []
 
+    def __eq__(self, other):
+        try:
+            return self.inventory_id == other.inventory_id and \
+                   self.inventory_sha1 == other.inventory_sha1 and \
+                   self.revision_id == other.revision_id and \
+                   self.timestamp == other.timestamp and \
+                   self.message == other.message and \
+                   self.timezone == other.timezone and \
+                   self.committer == other.committer and \
+                   self.parents == other.parents 
+        except AttributeError:
+            return False
 
     def __repr__(self):
         return "<Revision id %s>" % self.revision_id
-
         
     def to_element(self):
         from bzrlib.xml import Element, SubElement

=== modified file 'bzrlib/selftest/testrevision.py'
--- bzrlib/selftest/testrevision.py	2005-09-06 15:19:44 +0000
+++ bzrlib/selftest/testrevision.py	2005-09-07 16:31:54 +0000
@@ -14,7 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-from bzrlib.selftest import TestCaseInTempDir
+from bzrlib.selftest import TestCaseInTempDir, TestCase
 
 
 def make_branches():
@@ -177,3 +177,43 @@
         # create a revision, sign it, apply to the store.
         pass
 
+class TestOperators(TestCase):
+
+    def test___eq__(self):
+        from bzrlib.revision import Revision, RevisionReference
+        revision1 = Revision("invid", "sha", "revid", 100, "boo", "john", [])
+        revision2 = Revision("invid", "sha", "revid", 100, "boo", "john", [])
+        revision3 = Revision("invid", "sha", "rev2id", 100, "bp", "john", 
+                             [RevisionReference("revid")])
+        self.assertEqual(revision1, revision1)
+        self.assertEqual(revision1, revision2)
+        self.assertNotEqual(revision1, revision3)
+        self.assertEqual(revision2, revision1)
+        self.assertEqual(revision2, revision2)
+        self.assertNotEqual(revision2, revision3)
+        self.assertNotEqual(revision3, revision1)
+        self.assertNotEqual(revision3, revision2)
+        self.assertEqual(revision3, revision3)
+
+    def test__eq__reference(self):
+        from bzrlib.revision import Revision, RevisionReference
+        ref1 = RevisionReference('revid', '1'*40)
+        ref2 = RevisionReference('revid', '1'*40)
+        ref3 = RevisionReference('revid', '2'*40)
+        ref4 = RevisionReference('revid2', '3'*40)
+        self.assertEqual(ref1, ref1)
+        self.assertEqual(ref1, ref2)
+        self.assertNotEqual(ref1, ref3)
+        self.assertNotEqual(ref1, ref4)
+        self.assertEqual(ref2, ref1)
+        self.assertEqual(ref2, ref2)
+        self.assertNotEqual(ref2, ref3)
+        self.assertNotEqual(ref2, ref4)
+        self.assertNotEqual(ref3, ref1)
+        self.assertNotEqual(ref3, ref2)
+        self.assertEqual(ref3, ref3)
+        self.assertNotEqual(ref3, ref4)
+        self.assertNotEqual(ref4, ref1)
+        self.assertNotEqual(ref4, ref2)
+        self.assertNotEqual(ref4, ref3)
+        self.assertEqual(ref4, ref4)

